@@ -1,4 +1,3 @@
-from selenium.common import exceptions
 from selenium.webdriver.common.by import By
 
 
@@ -11,5 +10,5 @@ class InvalidLocatorStrategy(Exception):
         if not self.strategy:
             return f'InvalidLocatorStrategy: no selector strategy was provided. \n' \
                    f'Needs to be one of: {self.allowed_strategies}'
-        return f'InvalidLocatorStrategy: "{self.strategy}" is not a valid selector stragegy . \n' \
-               f'Needs to be one of: {self.allowed_strategies}'
\ No newline at end of file
+        return f'InvalidLocatorStrategy: "{self.strategy}" is not a valid selector strategy . \n' \
+               f'Needs to be one of: {self.allowed_strategies}'
